==> tomee-project-8.0.16-source-release.zip: tomee-project-8.0.16/arquillian/arquillian-tomee-tests/arquillian-tomee-webprofile-tests/src/test/java/org/apache/openejb/arquillian/tests/TestRun.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

package org.apache.openejb.arquillian.tests;

import java.io.IOException;
import java.io.PrintWriter;
import java.lang.reflect.Method;

import javax.servlet.ServletRequest;
import javax.servlet.ServletResponse;

public class TestRun {

	public static void run(ServletRequest req, ServletResponse resp, Object obj) throws IOException {
		final Class<?> clazz = obj.getClass();
        final Method[] methods = clazz.getMethods();

        resp.setContentType("text/plain");
        final PrintWriter writer = resp.getWriter();

        for (Method method : methods) {
            if (method.getName().startsWith("test")) {

                writer.print(method.getName());

                writer.print("=");

                try {
                    method.invoke(obj);
                    writer.println("true");
                } catch (Throwable e) {
                    writer.println("false");
                    writer.println("");
                    writer.println("STACKTRACE");
                    writer.println("");
                    e.printStackTrace(writer);
                }
            }
        }
	}

}

==> tomee-project-10.1.3-source-release.zip: tomee-project-10.1.3/arquillian/arquillian-tomee-tests/arquillian-tomee-webprofile-tests/src/test/java/org/apache/openejb/arquillian/tests/TestRun.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

package org.apache.openejb.arquillian.tests;

import java.io.IOException;
import java.io.PrintWriter;
import java.lang.reflect.Method;

import jakarta.servlet.ServletRequest;
import jakarta.servlet.ServletResponse;

public class TestRun {

	public static void run(ServletRequest req, ServletResponse resp, Object obj) throws IOException {
		final Class<?> clazz = obj.getClass();
        final Method[] methods = clazz.getMethods();

        resp.setContentType("text/plain");
        final PrintWriter writer = resp.getWriter();

        for (Method method : methods) {
            if (method.getName().startsWith("test")) {

                writer.print(method.getName());

                writer.print("=");

                try {
                    method.invoke(obj);
                    writer.println("true");
                } catch (Throwable e) {
                    writer.println("false");
                    writer.println("");
                    writer.println("STACKTRACE");
                    writer.println("");
                    e.printStackTrace(writer);
                }
            }
        }
	}

}
